elephant.spike\_train\_correlation.spike\_train\_timescale
==========================================================

.. currentmodule:: elephant.spike_train_correlation

.. autofunction:: spike_train_timescale